@@ -3,7 +3,7 @@
 #
 #   computes simulation envelopes 
 #
-#   $Revision: 2.113 $  $Date: 2022/05/22 00:47:39 $
+#   $Revision: 2.115 $  $Date: 2023/02/28 01:56:55 $
 #
 
 
@@ -327,21 +327,41 @@ envelopeEngine <-
       envir <- envir.here
     } else if(is.list(simulate) &&
               all(sapply(simulate, inherits, what=Xclass))) {
-      # The user-supplied list of point patterns will be used
+      #' The user-supplied list of point patterns will be used
       simtype <- "list"
       SimDataList <- simulate
-      # expression that will be evaluated
+      #' expression that will be evaluated
       simexpr <- expression(SimDataList[[i+nerr]])
       dont.complain.about(SimDataList)
       envir <- envir.here
-      # ensure that `i' is defined
+      #' ensure that `i' is defined
       i <- 1L
       nerr <- 0L
       maxnerr <- min(length(SimDataList)-nsim, maxnerr)
-      # any messages?
+      #' any messages?
       if(!is.null(mess <- attr(simulate, "internal"))) {
         # determine whether these point patterns are realisations of CSR
-        csr <- !is.null(mc <- mess$csr) && mc
+        csr <- isTRUE(mess$csr)
+      }
+    } else if(is.list(simulate) &&
+              all(sapply(simulate, is.list)) &&
+              all(lengths(simulate) == 1) &&
+              all(sapply((elements <- lapply(simulate, "[[", i=1)), inherits, what=Xclass))) {
+      #' malformed argument: list(list(ppp), list(ppp), ....) 
+      SimDataList <- elements
+      simtype <- "list"
+      #' expression that will be evaluated
+      simexpr <- expression(SimDataList[[i+nerr]])
+      dont.complain.about(SimDataList)
+      envir <- envir.here
+      #' ensure that `i' is defined
+      i <- 1L
+      nerr <- 0L
+      maxnerr <- min(length(SimDataList)-nsim, maxnerr)
+      #' any messages?
+      if(!is.null(mess <- attr(simulate, "internal"))) {
+        # determine whether these point patterns are realisations of CSR
+        csr <- isTRUE(mess$csr) 
       }
     } else stop(paste(sQuote("simulate"),
                       "should be an expression,",
@@ -982,7 +1002,7 @@ summary.envelope <- function(object, ...) {
   has.theo <- "theo" %in% fvnames(object, "*")
   csr.theo <- csr && has.theo
   use.theory <- if(is.null(use.theory)) csr.theo else (use.theory && has.theo)
-  fname <- deparse(attr(object, "ylab"))
+  fname <- short.deparse(attr(object, "ylab"))
   type <- if(V) paste("Pointwise", e$nSD, "sigma") else
           if(g) "Simultaneous" else "Pointwise"
   splat(type, "critical envelopes for", fname, 
